summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart/keximacroview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/kexipart/keximacroview.h')
-rw-r--r--kexi/plugins/macros/kexipart/keximacroview.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacroview.h b/kexi/plugins/macros/kexipart/keximacroview.h
index beed842e..0c44419b 100644
--- a/kexi/plugins/macros/kexipart/keximacroview.h
+++ b/kexi/plugins/macros/kexipart/keximacroview.h
@@ -42,6 +42,7 @@ class KexiTableItem;
class KexiMacroView : public KexiViewBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -49,10 +50,10 @@ class KexiMacroView : public KexiViewBase
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroView(KexiMainWindow *mainwin, QWidget *parent, ::KoMacro::Macro* const macro, const char* name = 0);
+ KexiMacroView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro, const char* name = 0);
/**
* Destructor.
@@ -94,7 +95,7 @@ class KexiMacroView : public KexiViewBase
* This slot will be invoked if Kexi's menuitem Data=>Execute
* got activated and will execute the Macro.
*/
- void execute(QObject* sender = 0);
+ void execute(TQObject* sender = 0);
protected:
@@ -49,10 +50,10 @@ class KexiMacroView : public KexiViewBase
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param parent The parent widget this widget should be displayed in.
+ * \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/